#
# spec file for package python-pyfakefs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python3-pyfakefs
Version:        3.4.3
Release:        150400.14.69
Summary:        Fake file system that mocks the Python file system modules
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://pyfakefs.org
Source:         https://github.com/jmcgeheeiv/pyfakefs/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM skip_fstest.patch bsc#1197845 mcepl@suse.com
# skip failing test test_mknod_raises_if_unsupported_options
Patch0:         skip_fstest.patch
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3
BuildArch:      noarch
%python_subpackages

%description
pyfakefs implements a fake file system that mocks the Python file system
modules. Using pyfakefs, your tests operate on a fake file system in
memory without touching the real disk. The software under test requires
no modification to work with pyfakefs.

%prep
%setup -q -n pyfakefs-%{version}
%autopatch -p1

# Clean shebangs
sed -i '1 {/^#!/d}' pyfakefs/tests/*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=C.UTF-8
%python_exec setup.py test

%files %{python_files}
%doc CHANGES* README*
%license COPYING*
%{python_sitelib}/*

%changelog
* Wed Mar 22 2023 mcepl@suse.com
- Use correctly named tarball.
* Sat Apr  9 2022 mcepl@suse.com
- Add skip_fstest.patch to follow the upstream lead in skipping
  failing test_mknod_raises_if_unsupported_options (bsc#1197845).
- Build actually requires full python3 package (because of the
  readline module), otherwise tests fail.
* Thu Jun 14 2018 kbabioch@suse.com
- Update to version 3.4.3
  - Added support for path-like objects as arguments in create_file(),
    create_dir(), create_symlink(), add_real_file() and add_real_directory()
  - Bugfixes:
  - tell after seek gave incorrect result in append mode
  - flushing file contents after truncate was incorrect under some conditions
  - readline() did not work correctly in binary mode
  - pathlib.Path.resolve() behaved incorrectly if the path does not exist
  - closed attribute was not implemented in fake file
  - add_real_directory did not behave correctly for nested paths
  - several functions did not behave correctly for paths ending with a
    path separator
* Tue Apr 17 2018 kbabioch@suse.com
- Initial packaging of version 3.4.1
